package com.ruoyi.model.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.model.mapper.AppPetsBreadMapper;
import com.ruoyi.model.domain.AppPetsBread;
import com.ruoyi.model.service.IAppPetsBreadService;

/**
 * 宠物品种Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
@Service
public class AppPetsBreadServiceImpl implements IAppPetsBreadService 
{
    @Autowired
    private AppPetsBreadMapper appPetsBreadMapper;

    /**
     * 查询宠物品种
     * 
     * @param petBreadId 宠物品种主键
     * @return 宠物品种
     */
    @Override
    public AppPetsBread selectAppPetsBreadByPetBreadId(Long petBreadId)
    {
        return appPetsBreadMapper.selectAppPetsBreadByPetBreadId(petBreadId);
    }

    /**
     * 查询宠物品种列表
     * 
     * @param appPetsBread 宠物品种
     * @return 宠物品种
     */
    @Override
    public List<AppPetsBread> selectAppPetsBreadList(AppPetsBread appPetsBread)
    {
        return appPetsBreadMapper.selectAppPetsBreadList(appPetsBread);
    }

    /**
     * 新增宠物品种
     * 
     * @param appPetsBread 宠物品种
     * @return 结果
     */
    @Override
    public int insertAppPetsBread(AppPetsBread appPetsBread)
    {
        return appPetsBreadMapper.insertAppPetsBread(appPetsBread);
    }

    /**
     * 修改宠物品种
     * 
     * @param appPetsBread 宠物品种
     * @return 结果
     */
    @Override
    public int updateAppPetsBread(AppPetsBread appPetsBread)
    {
        return appPetsBreadMapper.updateAppPetsBread(appPetsBread);
    }

    /**
     * 批量删除宠物品种
     * 
     * @param petBreadIds 需要删除的宠物品种主键
     * @return 结果
     */
    @Override
    public int deleteAppPetsBreadByPetBreadIds(Long[] petBreadIds)
    {
        return appPetsBreadMapper.deleteAppPetsBreadByPetBreadIds(petBreadIds);
    }

    /**
     * 删除宠物品种信息
     * 
     * @param petBreadId 宠物品种主键
     * @return 结果
     */
    @Override
    public int deleteAppPetsBreadByPetBreadId(Long petBreadId)
    {
        return appPetsBreadMapper.deleteAppPetsBreadByPetBreadId(petBreadId);
    }

    /**
     * 查询宠物品种列表
     *
     * @return 宠物品种集合
     */
    @Override
    public List<AppPetsBread> getAppPetsBreadList(){
        return appPetsBreadMapper.getAppPetsBreadList();
    }
}
